@@ -7,7 +7,7 @@ from ..datacube_transformations import DatacubeAxisTransformation
 class DatacubeMapper(DatacubeAxisTransformation):
     # Needs to implements DatacubeAxisTransformation methods
 
-    def __init__(self, name, mapper_options):
+    def __init__(self, name, mapper_options, datacube=None):
         self.transformation_options = mapper_options
         self.grid_type = mapper_options.type
         self.grid_resolution = mapper_options.resolution
